Software Summary and Comparisons
=================================

.. note:: This page is actively updated now, since many open-source software are missed here.

`pygmo <https://esa.github.io/pygmo2/>`_ is *a scientific Python library for massively parallel optimization*.
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.de
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.sade
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.de1220
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.pso
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.pso_gen
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.sea
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.sga
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.simulated_annealing
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.cmaes
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.xnes

`IOHanalyzer <https://github.com/IOHprofiler/IOHanalyzer>`_ is *a performance analyzer for Iterative Optimization Heuristics (IOHs)*.

`https://github.com/CMA-ES <https://github.com/CMA-ES>`_ is *a collection of various implementations of the powerful CMA-ES algorithm*.
  * https://github.com/CMA-ES/c-cmaes (C)
  * https://github.com/CMA-ES/libcmaes (C++)
  * https://github.com/CMA-ES/pycma (Python)

`pymoo <https://pymoo.org/>`_ *offers state of the art single- and multi-objective optimization algorithms*.
  * https://pymoo.org/algorithms/soo/cmaes.html
  * https://pymoo.org/algorithms/soo/de.html
  * https://pymoo.org/algorithms/soo/es.html
  * https://pymoo.org/algorithms/soo/ga.html
  * https://pymoo.org/algorithms/soo/g3pcx.html
  * https://pymoo.org/algorithms/soo/isres.html
  * https://pymoo.org/algorithms/soo/nelder.html
  * https://pymoo.org/algorithms/soo/pattern.html
  * https://pymoo.org/algorithms/soo/pso.html
  * https://pymoo.org/algorithms/soo/sres.html

https://nlopt.readthedocs.io/en/latest/

https://coin-or.github.io/Ipopt/

https://scipy.org/

Python
------

* https://esa.github.io/pygmo2/
* https://github.com/CMA-ES/pycma
* https://github.com/fmfn/BayesianOptimization
* https://pymoo.org/

R
-

https://cran.r-project.org/web/views/Optimization.html

* https://cran.r-project.org/web/packages/CEoptim/index.html
* https://cran.r-project.org/web/packages/cmaes/index.html
* https://cran.r-project.org/web/packages/DEoptimR/index.html

  * Currently, it only provides an implementation of the `jDE` algorithm by Brest et al. (2006).

Matlab
------

* https://github.com/blockchain-group/DIRECTGO

C
-

* https://www.egr.msu.edu/~kdeb/codes/g3pcx/g3pcx.tar (G3PCX)
